@@ -17,7 +17,7 @@ TrackView::TrackView(Spotify::Session* pSession, QWidget* parent) :
         m_pQueueView = new QueueView(m_pSession,this);
 
         //init the track listview instance
-        m_pTrackListView = new QListView(this);
+        m_pTrackListView = new CListView(this);
         m_pTrackListModel = new QStandardItemModel(this);
         m_pTrackListDelegate = new ListViewDelegate(this);
         m_pTrackListDelegate->setSubHeaderFontPointSize(14);
@@ -53,6 +53,17 @@ TrackView::~TrackView()
 {
 }
 
+bool TrackView::getQueueViewUpdateBufPos()
+{
+    //returns the update buffer position status for the TrackView owned QueueView instance
+    if(m_pQueueView)
+    {
+        return m_pQueueView->getUpdateBufferPos();
+    }
+    else
+        return true;
+}
+
 void TrackView::closeEvent(QCloseEvent* evt)
 {
     //Notification received when view closed
@@ -161,7 +172,7 @@ void TrackView::OnTrackActivated(QModelIndex trackIndex)
 
      m_pTrackListView->setEnabled(false); //disable table temporarily
 
-        int trackPos = trackIndex.data(Qt::UserRole).toInt();
+      int trackPos = trackIndex.data(Qt::UserRole).toInt();
 
         if(m_pPlaylist) //track from playlist
             track = m_pPlaylist->getTrack(trackPos);
@@ -218,6 +229,7 @@ void TrackView::setPlayQueue()
     {
         m_pQueueView->setNowPlaying(PlayQueue,0,true,0,0,true);
         m_pQueueView->setActive(true,m_Shuffle);
+        m_pQueueView->setUpdateBufferPos(true); //allow update of buffering progress
         emit activeQueueViewChanged(true,m_Shuffle); //notify about active queue view change
         m_pQueueView->show();
     }
@@ -260,8 +272,9 @@ void TrackView::addTracks(Spotify::Playlist* playlist)
     }
 
     if(m_pTrackListModel->rowCount()>0)
-    {
-        QModelIndex index = m_pTrackListModel->index(0,0);
+    { //scroll to top, no current / selected row by default
+        m_pTrackListView->scrollToTop();
+        QModelIndex index = m_pTrackListModel->index(-1,-1);
         m_pTrackListView->setCurrentIndex(index);
     }
 
@@ -297,7 +310,6 @@ void TrackView::addTrackListModelItem(Spotify::Track* track, int pos)
     }
     trackItem->setData(strSubHeader,ListViewDelegate::subHeaderLeftJustifyRole);
     m_pTrackListModel->appendRow(trackItem);
-
 }
 
 void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
@@ -311,19 +323,35 @@ void TrackView::addTracks(const QList<Spotify::Track*>& trackList)
 
      for(int trackPos = 0; trackPos < trackList.size(); trackPos++)
      {
-             Spotify::Track* currTrack = trackList.at(trackPos);
-             if(currTrack)
-             {
-                 addTrackListModelItem(currTrack,trackPos);
-             }
+         Spotify::Track* currTrack = trackList.at(trackPos);
+         if(currTrack)
+         {
+           addTrackListModelItem(currTrack,trackPos);
+         }
      }
 
      if(m_pTrackListModel->rowCount()>0)
-     {
-         QModelIndex index = m_pTrackListModel->index(0,0);
+     { //scroll to top, no current / selected row by default
+         m_pTrackListView->scrollToTop();
+         QModelIndex index = m_pTrackListModel->index(-1,-1);
          m_pTrackListView->setCurrentIndex(index);
      }
 
      setAttribute(Qt::WA_Maemo5ShowProgressIndicator,false);
 }
 
+void TrackView::keyPressEvent(QKeyEvent *evt)
+{
+    //Overriden keyPressEvent handler
+
+    if(evt->key()==Qt::Key_Left)
+    {
+        close(); //hide the view
+        evt->accept();
+    }
+    else
+    {
+        QMainWindow::keyPressEvent(evt);
+    }
+}
+
